@@ -10,7 +10,7 @@ if __name__ == '__main__':
         db.create_all()
         db.session.commit()
         
-        if Role.quey.get(1).name != "admin":
+        if Role.query.count() == 0 :
             # add default role
             user_role = Role(name='user')
             admin_role = Role(name='admin')
